from typing import Optional

import streamlit.components.v1 as components
from keplergl import KeplerGl


def keplergl_static(
    fig: KeplerGl,
    height: Optional[int] = None,
    width: Optional[int] = None,
    center_map=False,
    read_only=False,
) -> components.html:
    """
    Renders `keplergl.KeplerGl` map figure in a Streamlit app. This method is a static Streamlit Component,
    thus no information is passed back from KeplerGL on browser interaction.

    Args:
        fig: `keplergl.KeplerGl` map figure.
        height: Fixed pixel height of the map, optional. By default determined by the height setting of the KeplerGl.
          keplergl figure object. Setting width and height explcitly might result in non optimal layout on other devices.
        width: Fixed pixel width of the map, optional. By default the adjusts to the streamlit layout option, e.g.
          automatically adjusted to streamlit column or container width.
        center_map: The bound of the map will be centered on the current map data, default False.
        read_only: Hide side panel to disable map customization, default False.

    Example:
        ```python
            >>> map_1 = KeplerGl()
            >>> keplergl_static(map_1)
        ```
    """
    try:
        html = fig._repr_html_(center_map=center_map, read_only=read_only)
    except AttributeError:
        raise TypeError(
            "fig argument has to be a keplergl map object of type keplergl.KeplerGl!"
        )

    if height is None:
        height = fig.height
    return components.html(html, height=height + 10, width=width)



import setuptools
from pathlib import Path

parent_dir = Path(__file__).resolve().parent

setuptools.setup(
    name="streamlit-keplergl",
    version="0.3.0",
    author="Christoph Rieke",
    author_email="",
    description="Streamlit Component for rendering kepler.gl maps",
    long_description=parent_dir.joinpath("README.md").read_text(),
    long_description_content_type="text/markdown",
    url="https://github.com/chrieke/streamlit-keplergl",
    license="MIT",
    packages=setuptools.find_packages(exclude=("tests", "docs", "examples")),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.6",
    install_requires=parent_dir.joinpath("requirements.txt").read_text().splitlines(),
)
